Welcome to ataraxis-base-utilities API documentation page
=========================================================

ataraxis-base-utilities is a Python library that provides a minimalistic set of shared utility functions used to
support most other Sun Lab projects.

This library is part of the broader 'Ataraxis' science-automation project, developed in the
`Sun Lab <https://neuroai.github.io/sunlab/>`_ at Cornell University.

This website only contains the API documentation for the classes and methods offered by this library. See the project
GitHub repository for installation instructions and library usage examples:
`ataraxis-base-utilities GitHub repository <https://github.com/Sun-Lab-NBB/ataraxis-base-utilities>`_.

.. _`ataraxis-base-utilities GitHub repository`: https://github.com/Sun-Lab-NBB/ataraxis-base-utilities
.. _`Sun Lab`: https://neuroai.github.io/sunlab/
